[openib-general] [PATCH] rename functions in ip2pr to linux standard conventions

Tom Duffy tduffy at sun.com
Tue Aug 10 11:43:50 PDT 2004


This patch renames the functions in ip2pr to be in Linux standard naming
conventions.

Signed-by: Tom Duffy <tduffy at sun.com> with permission from Sun legal.

Index: drivers/infiniband/ulp/ipoib/ip2pr_export.h
===================================================================
--- drivers/infiniband/ulp/ipoib/ip2pr_export.h	(revision 622)
+++ drivers/infiniband/ulp/ipoib/ip2pr_export.h	(working copy)
@@ -65,30 +65,30 @@
  *   arg          - supplied argument is returned in callback function
  *   plid         - pointer to storage for identifier of this query.
  */
-s32 tsIp2prPathRecordLookup(u32 dst_addr,	/* NBO */
-			    u32 src_addr,	/* NBO */
-			    u8 localroute,
-			    s32 bound_dev_if,
-			    tIP2PR_PATH_LOOKUP_FUNC func,
-			    void *arg,
-			    tIP2PR_PATH_LOOKUP_ID *plid);
+s32 ip2pr_path_record_lookup(u32 dst_addr,	/* NBO */
+			     u32 src_addr,	/* NBO */
+			     u8 localroute,
+			     s32 bound_dev_if,
+			     tIP2PR_PATH_LOOKUP_FUNC func,
+			     void *arg,
+			     tIP2PR_PATH_LOOKUP_ID *plid);
 
 /*
  * address lookup cancel
  */
-s32 tsIp2prPathRecordCancel(tIP2PR_PATH_LOOKUP_ID plid);
+s32 ip2pr_path_record_cancel(tIP2PR_PATH_LOOKUP_ID plid);
 
 /*
  * Giver a Source and Destination GID, get the path record
  */
-s32 tsGid2prLookup(tTS_IB_GID src_gid,
+s32 gid2pr_lookup(tTS_IB_GID src_gid,
 		   tTS_IB_GID dst_gid,
 		   u16 pkey,
 		   tGID2PR_LOOKUP_FUNC func,
 		   void *arg,
 		   tIP2PR_PATH_LOOKUP_ID * plid);
 
-s32 tsGid2prCancel(tIP2PR_PATH_LOOKUP_ID plid);
+s32 gid2pr_cancel(tIP2PR_PATH_LOOKUP_ID plid);
 #endif
 
 struct ip2pr_lookup_param {
Index: drivers/infiniband/ulp/ipoib/ip2pr_link.c
===================================================================
--- drivers/infiniband/ulp/ipoib/ip2pr_link.c	(revision 622)
+++ drivers/infiniband/ulp/ipoib/ip2pr_link.c	(working copy)
@@ -47,7 +47,7 @@
       gid_lock:SPIN_LOCK_UNLOCKED
 };
 
-s32 _tsIp2PrnDelete(struct ip2pr_gid_pr_element *pr_elmt);
+static s32 ip2pr_delete(struct ip2pr_gid_pr_element *pr_elmt);
 
 static tTS_IB_GID nullgid = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 
@@ -55,32 +55,25 @@
       ((TS_IP2PR_PATH_LOOKUP_INVALID == ++_tsIp2prPathLookupId) ? \
        ++_tsIp2prPathLookupId : _tsIp2prPathLookupId)
 
-/* --------------------------------------------------------------------- */
-/*                                                                       */
-/* Path Record lookup caching                                            */
-/*                                                                       */
-/* --------------------------------------------------------------------- */
-/* ========================================================================= */
-/*.._tsIp2prPathElementLookup -- lookup a path record entry */
-static struct ip2pr_path_element *_tsIp2prPathElementLookup(u32 ip_addr)
+/**
+ * Path Record lookup caching
+ */
+
+/* ip2pr_path_element_lookup -- lookup a path record entry */
+static struct ip2pr_path_element *ip2pr_path_element_lookup(u32 ip_addr)
 {
 	struct ip2pr_path_element *path_elmt;
 
 	for (path_elmt = _tsIp2prLinkRoot.path_list;
-	     NULL != path_elmt; path_elmt = path_elmt->next) {
-
-		if (ip_addr == path_elmt->dst_addr) {
-
+	     NULL != path_elmt; path_elmt = path_elmt->next)
+		if (ip_addr == path_elmt->dst_addr)
 			break;
-		}		/* if */
-	}			/* for */
 
 	return path_elmt;
-}				/* _tsIp2prPathElementLookup */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prPathElementCreate -- create an entry for a path record element */
-static s32 _tsIp2prPathElementCreate(u32 dst_addr, u32 src_addr,
+/* ip2pr_path_element_create -- create an entry for a path record element */
+static s32 ip2pr_path_element_create(u32 dst_addr, u32 src_addr,
 				     tTS_IB_PORT hw_port, struct ib_device *ca,
 				     struct ib_path_record *path_r,
 				     struct ip2pr_path_element **return_elmt)
@@ -93,11 +86,9 @@
 	TS_CHECK_NULL(_tsIp2prLinkRoot.path_cache, -EINVAL);
 
 	path_elmt = kmem_cache_alloc(_tsIp2prLinkRoot.path_cache, SLAB_ATOMIC);
-	if (NULL == path_elmt) {
-
+	if (NULL == path_elmt)
 		return -ENOMEM;
-	}
-	/* if */
+
 	memset(path_elmt, 0, sizeof(*path_elmt));
 
 	spin_lock_irqsave(&_tsIp2prLinkRoot.path_lock, flags);
@@ -105,10 +96,9 @@
 	_tsIp2prLinkRoot.path_list = path_elmt;
 	path_elmt->p_next = &_tsIp2prLinkRoot.path_list;
 
-	if (NULL != path_elmt->next) {
-
+	if (NULL != path_elmt->next)
 		path_elmt->next->p_next = &path_elmt->next;
-	}			/* if */
+
 	spin_unlock_irqrestore(&_tsIp2prLinkRoot.path_lock, flags);
 	/*
 	 * set values
@@ -123,11 +113,10 @@
 	*return_elmt = path_elmt;
 
 	return 0;
-}				/* _tsIp2prPathElementCreate */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prPathElementDestroy -- destroy an entry for a path record element */
-static s32 _tsIp2prPathElementDestroy(struct ip2pr_path_element *path_elmt)
+/* ip2pr_path_element_destroy -- destroy an entry for a path record element */
+static s32 ip2pr_path_element_destroy(struct ip2pr_path_element *path_elmt)
 {
 	unsigned long flags;
 
@@ -136,11 +125,9 @@
 
 	spin_lock_irqsave(&_tsIp2prLinkRoot.path_lock, flags);
 	if (NULL != path_elmt->p_next) {
-
-		if (NULL != path_elmt->next) {
+		if (NULL != path_elmt->next)
 			path_elmt->next->p_next = path_elmt->p_next;
-		}
-		/* if */
+
 		*(path_elmt->p_next) = path_elmt->next;
 
 		path_elmt->p_next = NULL;
@@ -151,11 +138,10 @@
 	kmem_cache_free(_tsIp2prLinkRoot.path_cache, path_elmt);
 
 	return 0;
-}				/* _tsIp2prPathElementDestroy */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prPathLookupComplete -- complete the resolution of a path record */
-static s32 _tsIp2prPathLookupComplete(tIP2PR_PATH_LOOKUP_ID plid,
+/* ip2pr_path_lookup_complete -- complete the resolution of a path record */
+static s32 ip2pr_path_lookup_complete(tIP2PR_PATH_LOOKUP_ID plid,
 				      s32 status,
 				      struct ip2pr_path_element *path_elmt,
 				      void *funcptr, void *arg)
@@ -178,17 +164,16 @@
 
 		return func(plid, status, 0, 0, 0, NULL, NULL, arg);
 	}			/* else */
-}				/* _tsIp2prPathLookupComplete */
+}
 
-/* --------------------------------------------------------------------- */
-/*                                                                       */
-/* module specific functions                                             */
-/*                                                                       */
-/* --------------------------------------------------------------------- */
-/* ========================================================================= */
-/*.._tsIp2prIpoibWaitDestroy -- destroy an entry for an outstanding request */
-static s32 _tsIp2prIpoibWaitDestroy
-    (struct ip2pr_ipoib_wait *ipoib_wait, IP2PR_USE_LOCK use_lock) {
+/**
+ * module specific functions
+ */
+
+/* ip2pr_ipoib_wait_destroy -- destroy an entry for an outstanding request */
+static s32 ip2pr_ipoib_wait_destroy(struct ip2pr_ipoib_wait *ipoib_wait,
+				    IP2PR_USE_LOCK use_lock)
+{
 	unsigned long flags = 0;
 
 	TS_CHECK_NULL(ipoib_wait, -EINVAL);
@@ -213,11 +198,10 @@
 	kmem_cache_free(_tsIp2prLinkRoot.wait_cache, ipoib_wait);
 
 	return 0;
-}				/* _tsIp2prIpoibWaitDestroy */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prIpoibWaitTimeout -- timeout function for link resolution */
-static void _tsIp2prIpoibWaitTimeout(void *arg)
+/* ip2pr_ipoib_wait_timeout -- timeout function for link resolution */
+static void ip2pr_ipoib_wait_timeout(void *arg)
 {
 	struct ip2pr_ipoib_wait *ipoib_wait = (struct ip2pr_ipoib_wait *)arg;
 	s32 result;
@@ -238,7 +222,7 @@
 	if (0 < TS_IP2PR_IPOIB_FLAGS_EMPTY(ipoib_wait)) {
 
 		result =
-		    _tsIp2prIpoibWaitDestroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
+		    ip2pr_ipoib_wait_destroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
 
 		return;
@@ -255,7 +239,7 @@
 		ipoib_wait->timer.run_time =
 		    jiffies + (ipoib_wait->prev_timeout * HZ) +
 		    (jiffies & 0x0f);
-		ipoib_wait->timer.function = _tsIp2prIpoibWaitTimeout;
+		ipoib_wait->timer.function = ip2pr_ipoib_wait_timeout;
 		ipoib_wait->timer.arg = ipoib_wait;
 		tsKernelTimerAdd(&ipoib_wait->timer);
 
@@ -271,35 +255,30 @@
 			 ipoib_wait->dev,
 			 ipoib_wait->src_addr,
 			 NULL, ipoib_wait->dev->dev_addr, NULL);
-	} /* if */
-	else {
-
-		result = _tsIp2prPathLookupComplete(ipoib_wait->plid,
+	} else {
+		result = ip2pr_path_lookup_complete(ipoib_wait->plid,
 						    -EHOSTUNREACH,
 						    NULL,
 						    ipoib_wait->func,
 						    ipoib_wait->arg);
-		if (0 > result) {
-
+		if (0 > result)
 			TS_TRACE(MOD_IP2PR, T_VERY_VERBOSE, TRACE_FLOW_WARN,
 				 "FUNC: Error <%d> timing out address resolution. <%08x>",
 				 result, ipoib_wait->dst_addr);
-		}
-		/* if */
+
 		TS_IP2PR_IPOIB_FLAG_CLR_FUNC(ipoib_wait);
 
-		result =
-		    _tsIp2prIpoibWaitDestroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
+		result = ip2pr_ipoib_wait_destroy(ipoib_wait,
+						  IP2PR_LOCK_NOT_HELD);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
-	}			/* else */
+	}
 
 	return;
-}				/* _tsIp2prIpoibWaitTimeout */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prIpoibWaitCreate -- create an entry for an outstanding request */
+/* ip2pr_ipoib_wait_create -- create an entry for an outstanding request */
 static struct ip2pr_ipoib_wait *
-_tsIp2prIpoibWaitCreate(tIP2PR_PATH_LOOKUP_ID plid, u32 dst_addr, u32 src_addr,
+ip2pr_ipoib_wait_create(tIP2PR_PATH_LOOKUP_ID plid, u32 dst_addr, u32 src_addr,
 			u8 localroute, u32 bound_dev_if,
 			tIP2PR_PATH_LOOKUP_FUNC func, void *arg, s32 ltype)
 {
@@ -319,7 +298,7 @@
 			tsKernelTimerInit(&ipoib_wait->timer);
 			ipoib_wait->timer.run_time = jiffies +
 			    (_tsIp2prLinkRoot.retry_timeout * HZ);
-			ipoib_wait->timer.function = _tsIp2prIpoibWaitTimeout;
+			ipoib_wait->timer.function = ip2pr_ipoib_wait_timeout;
 			ipoib_wait->timer.arg = ipoib_wait;
 		}
 		ipoib_wait->type = ltype;
@@ -347,11 +326,10 @@
 	}
 	/* if */
 	return ipoib_wait;
-}				/* _tsIp2prIpoibWaitCreate */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prIpoibWaitListInsert -- insert an entry into the wait list */
-static s32 _tsIp2prIpoibWaitListInsert(struct ip2pr_ipoib_wait *ipoib_wait)
+/* ip2pr_ipoib_wait_list_insert -- insert an entry into the wait list */
+static s32 ip2pr_ipoib_wait_list_insert(struct ip2pr_ipoib_wait *ipoib_wait)
 {
 	unsigned long flags;
 
@@ -384,12 +362,14 @@
 	}
 
 	return 0;
-}				/* _tsIp2prIpoibWaitListInsert */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prIpoibWaitPlidLookup -- lookup an entry for an outstanding request */
+/*
+ * ip2pr_ipoib_waith_plid_lookup -- lookup an entry for an outstanding
+ * request
+ */
 static struct ip2pr_ipoib_wait *
-tsIp2prIpoibWaitPlidLookup(tIP2PR_PATH_LOOKUP_ID plid)
+ip2pr_ipoib_wait_plid_lookup(tIP2PR_PATH_LOOKUP_ID plid)
 {
 	unsigned long flags;
 	struct ip2pr_ipoib_wait *ipoib_wait;
@@ -406,12 +386,14 @@
 	spin_unlock_irqrestore(&_tsIp2prLinkRoot.wait_lock, flags);
 
 	return ipoib_wait;
-}				/* _tsIp2prIpoibWaitPlidLookup */
+}
 
-/* ========================================================================= */
-/*..tsIp2prPathElementTableDump - dump the path record element table to proc */
-s32 tsIp2prPathElementTableDump(char *buffer, s32 max_size, s32 start_index,
-				long *end_index)
+/*
+ * ip2pr_path_element_table_dump -- dump the path record element table to
+ * proc
+ */
+s32 ip2pr_path_element_table_dump(char *buffer, s32 max_size, s32 start_index,
+				  long *end_index)
 {
 	struct ip2pr_path_element *path_elmt;
 	s32 counter = 0;
@@ -475,13 +457,15 @@
 	}
 	/* if */
 	return offset;
-}				/* tsIp2prPathElementTableDump */
+}
 
-/* ========================================================================= */
-/*..tsIp2prIpoibWaitTableDump - dump the address resolution wait table to proc */
+/*
+ * ip2pr_ipoib_wait_table_dump -- dump the address resolution wait table
+ * to proc
+ */
 s32
-tsIp2prIpoibWaitTableDump(char *buffer, s32 max_size, s32 start_index,
-			  long *end_index)
+ip2pr_ipoib_wait_table_dump(char *buffer, s32 max_size, s32 start_index,
+			    long *end_index)
 {
 	struct ip2pr_ipoib_wait *ipoib_wait;
 	s32 counter = 0;
@@ -535,11 +519,11 @@
 	}
 	/* if */
 	return offset;
-}				/* tsIp2prIpoibWaitTableDump */
+}
 
-/* ..tsIp2prProcReadInt. dump integer value to /proc file */
-s32 tsIp2prProcReadInt(char *buffer, s32 max_size, s32 start_index,
-		       long *end_index, int val)
+/* ip2pr_proc_read_int -- dump integer value to /proc file */
+s32 ip2pr_proc_read_int(char *buffer, s32 max_size, s32 start_index,
+		        long *end_index, int val)
 {
 	s32 offset = 0;
 
@@ -553,94 +537,73 @@
 	return (offset);
 }
 
-/* ..tsIp2prProcMaxRetriesRead. dump current retry value */
-s32 tsIp2prProcRetriesRead(char *buffer, s32 max_size, s32 start_index,
-			   long *end_index)
+/* ip2pr_proc_retries_read -- dump current retry value */
+s32 ip2pr_proc_retries_read(char *buffer, s32 max_size, s32 start_index,
+			    long *end_index)
 {
-
-	return (tsIp2prProcReadInt(buffer,
-				   max_size,
-				   start_index,
-				   end_index, _tsIp2prLinkRoot.max_retries));
+	return (ip2pr_proc_read_int(buffer, max_size, start_index,
+				    end_index, _tsIp2prLinkRoot.max_retries));
 }
 
-/* ..tsIp2prProcTimeoutRead. dump current timeout value */
-s32 tsIp2prProcTimeoutRead(char *buffer, s32 max_size, s32 start_index,
-			   long *end_index)
+/* ip2pr_proc-timeout_read -- dump current timeout value */
+s32 ip2pr_proc_timeout_read(char *buffer, s32 max_size, s32 start_index,
+			    long *end_index)
 {
-
-	return (tsIp2prProcReadInt(buffer,
-				   max_size,
-				   start_index,
-				   end_index, _tsIp2prLinkRoot.retry_timeout));
+	return (ip2pr_proc_read_int(buffer, max_size, start_index,
+				    end_index, _tsIp2prLinkRoot.retry_timeout));
 }
 
-/* ..tsIp2prProcBackoutRead. dump current backout value */
-s32 tsIp2prProcBackoffRead(char *buffer, s32 max_size, s32 start_index,
+/* ip2pr_proc_backoff_read -- dump current backoff value */
+s32 ip2pr_proc_backoff_read(char *buffer, s32 max_size, s32 start_index,
 			   long *end_index)
 {
-
-	return (tsIp2prProcReadInt(buffer,
-				   max_size,
-				   start_index,
-				   end_index, _tsIp2prLinkRoot.backoff));
+	return (ip2pr_proc_read_int(buffer, max_size, start_index,
+				    end_index, _tsIp2prLinkRoot.backoff));
 }
 
-/* ..tsIp2prProcCacheTimeoutRead. dump current cache timeout value */
-s32 tsIp2prProcCacheTimeoutRead(char *buffer, s32 max_size, s32 start_index,
-				long *end_index)
+/* ip2pr_proc_cache_timeout_read -- dump current cache timeout value */
+s32 ip2pr_proc_cache_timeout_read(char *buffer, s32 max_size, s32 start_index,
+				  long *end_index)
 {
-
-	return (tsIp2prProcReadInt(buffer,
-				   max_size,
-				   start_index,
-				   end_index, _tsIp2prLinkRoot.cache_timeout));
+	return (ip2pr_proc_read_int(buffer, max_size, start_index,
+				    end_index, _tsIp2prLinkRoot.cache_timeout));
 }
 
-/* ..tsIp2prProcMaxRetriesRead. dump current retry value */
-s32 tsIp2prProcTotalReq(char *buffer, s32 max_size, s32 start_index,
-			long *end_index)
+/* ip2pr_proc_total_req -- dump current retry value */
+s32 ip2pr_proc_total_req(char *buffer, s32 max_size, s32 start_index,
+			 long *end_index)
 {
-
-	return (tsIp2prProcReadInt(buffer,
-				   max_size,
-				   start_index, end_index, ip2pr_total_req));
+	return (ip2pr_proc_read_int(buffer, max_size, start_index, end_index,
+				    ip2pr_total_req));
 }
 
-/* ..tsIp2prProcMaxRetriesRead. dump current retry value */
-s32 tsIp2prProcArpTimeout(char *buffer, s32 max_size, s32 start_index,
+/* ip2pr_proc_arp_timeout -- dump current retry value */
+s32 ip2pr_proc_arp_timeout(char *buffer, s32 max_size, s32 start_index,
 			  long *end_index)
 {
-
-	return (tsIp2prProcReadInt(buffer,
-				   max_size,
-				   start_index, end_index, ip2pr_arp_timeout));
+	return (ip2pr_proc_read_int(buffer, max_size, start_index, end_index,
+				    ip2pr_arp_timeout));
 }
 
-/* ..tsIp2prProcMaxRetriesRead. dump current retry value */
-s32 tsIp2prProcPathTimeout(char *buffer, s32 max_size, s32 start_index,
+/* ip2pr_proc_path_timeout -- dump current retry value */
+s32 ip2pr_proc_path_timeout(char *buffer, s32 max_size, s32 start_index,
 			   long *end_index)
 {
-
-	return (tsIp2prProcReadInt(buffer,
-				   max_size,
-				   start_index, end_index, ip2pr_path_timeout));
+	return (ip2pr_proc_read_int(buffer, max_size, start_index, end_index,
+				    ip2pr_path_timeout));
 }
 
-/* ..tsIp2prProcMaxRetriesRead. dump current retry value */
-s32 tsIp2prProcTotalFail(char *buffer, s32 max_size, s32 start_index,
+/* ip2pr_proc_total_fail -- dump current retry value */
+s32 ip2pr_proc_total_fail(char *buffer, s32 max_size, s32 start_index,
 			 long *end_index)
 {
-
-	return (tsIp2prProcReadInt(buffer,
-				   max_size,
-				   start_index, end_index, ip2pr_total_fail));
+	return (ip2pr_proc_read_int(buffer, max_size, start_index, end_index,
+				    ip2pr_total_fail));
 }
 
-/* ..tsIp2prProcWriteInt. scan integer value from /proc file */
-ssize_t tsIp2prProcWriteInt(struct file * file,
-			    const char *buffer,
-			    size_t count, loff_t * pos, int *val)
+/* ip2pr_proc_write_int -- scan integer value from /proc file */
+ssize_t ip2pr_proc_write_int(struct file * file, const char *buffer,
+			     size_t count, loff_t * pos, int *val)
 {
 	char kernel_buf[256];
 	int ret;
@@ -662,71 +625,68 @@
 	return (ret);
 }
 
-/* ..tsIp2prProcMaxRetriesWrite. scan max retries value */
-ssize_t tsIp2prProcRetriesWrite(struct file * file,
-				const char *buffer, size_t count, loff_t * pos)
+/* ip2pr_proc_retries_write -- scan max retries value */
+ssize_t ip2pr_proc_retries_write(struct file * file, const char *buffer,
+				 size_t count, loff_t * pos)
 {
 	int val;
 	int ret;
 
-	ret = tsIp2prProcWriteInt(file, buffer, count, pos, &val);
+	ret = ip2pr_proc_write_int(file, buffer, count, pos, &val);
 	if (val <= TS_IP2PR_PATH_MAX_RETRIES)
 		_tsIp2prLinkRoot.max_retries = val;
 
 	return (ret);
 }
 
-/* ..tsIp2prProcTimeoutWrite. scan timeout value */
-ssize_t tsIp2prProcTimeoutWrite(struct file * file,
-				const char *buffer, size_t count, loff_t * pos)
+/* ip2pr_proc_timeout_write -- scan timeout value */
+ssize_t ip2pr_proc_timeout_write(struct file * file, const char *buffer,
+				 size_t count, loff_t * pos)
 {
 	int val;
 	int ret;
 
-	ret = tsIp2prProcWriteInt(file, buffer, count, pos, &val);
+	ret = ip2pr_proc_write_int(file, buffer, count, pos, &val);
 	if (val <= TS_IP2PR_MAX_DEV_PATH_WAIT)
 		_tsIp2prLinkRoot.retry_timeout = val;
 
 	return (ret);
 }
 
-/* ..tsIp2prProcBackoutWrite. scan backout value */
-ssize_t tsIp2prProcBackoffWrite(struct file * file,
-				const char *buffer, size_t count, loff_t * pos)
+/* ip2pr_proc_backoff_write -- scan backoff value */
+ssize_t ip2pr_proc_backoff_write(struct file * file, const char *buffer,
+				 size_t count, loff_t * pos)
 {
 	int val;
 	int ret;
 
-	ret = tsIp2prProcWriteInt(file, buffer, count, pos, &val);
+	ret = ip2pr_proc_write_int(file, buffer, count, pos, &val);
 	if (val <= TS_IP2PR_PATH_MAX_BACKOFF)
 		_tsIp2prLinkRoot.backoff = val;
 
 	return (ret);
 }
 
-/* ..tsIp2prProcCacheTimeoutWrite. scan cache timeout value */
-ssize_t tsIp2prProcCacheTimeoutWrite(struct file * file,
-				     const char *buffer,
-				     size_t count, loff_t * pos)
+/* ip2pr_proc_cache_timeout_write -- scan cache timeout value */
+ssize_t ip2pr_proc_cache_timeout_write(struct file * file, const char *buffer,
+				       size_t count, loff_t * pos)
 {
 	int val;
 	int ret;
 
-	ret = tsIp2prProcWriteInt(file, buffer, count, pos, &val);
+	ret = ip2pr_proc_write_int(file, buffer, count, pos, &val);
 	if (val <= TS_IP2PR_PATH_MAX_CACHE_TIMEOUT)
 		_tsIp2prLinkRoot.cache_timeout = val;
 
 	return (ret);
 }
 
-/* --------------------------------------------------------------------- */
-/*                                                                       */
-/* Path record completion                                                */
-/*                                                                       */
-/* --------------------------------------------------------------------- */
-/* ========================================================================= */
-/*.._tsIp2prPathRecordComplete -- path lookup complete, save result */
-static s32 _tsIp2prPathRecordComplete(tTS_IB_CLIENT_QUERY_TID tid, s32 status,
+/**
+ * Path record completion
+ */
+
+/* ip2pr_path_record_complete -- path lookup complete, save result */
+static s32 ip2pr_path_record_complete(tTS_IB_CLIENT_QUERY_TID tid, s32 status,
 				      struct ib_path_record *path,
 				      s32 remaining, void *arg)
 {
@@ -780,7 +740,7 @@
 						       (ipoib_wait->
 							prev_timeout * HZ) +
 						       (jiffies & 0x0f), 0,
-						       _tsIp2prPathRecordComplete,
+						       ip2pr_path_record_complete,
 						       ipoib_wait,
 						       &ipoib_wait->tid);
 			if (0 != result) {
@@ -809,7 +769,7 @@
 				     (path->dgid + sizeof(u64))),
 			 path->dlid);
 
-		result = _tsIp2prPathElementCreate(ipoib_wait->dst_addr,
+		result = ip2pr_path_element_create(ipoib_wait->dst_addr,
 						   ipoib_wait->src_addr,
 						   ipoib_wait->hw_port,
 						   ipoib_wait->ca,
@@ -836,7 +796,7 @@
 
 	if (0 < TS_IP2PR_IPOIB_FLAG_GET_FUNC(ipoib_wait)) {
 
-		result = _tsIp2prPathLookupComplete(ipoib_wait->plid,
+		result = ip2pr_path_lookup_complete(ipoib_wait->plid,
 						    status,
 						    path_elmt,
 						    ipoib_wait->func,
@@ -847,28 +807,23 @@
 				 "PATH: Error <%d> completing Path Record Lookup.",
 				 result);
 		}
-		/* if */
 		TS_IP2PR_IPOIB_FLAG_CLR_FUNC(ipoib_wait);
 	}
-	/* if */
 	if (0 < TS_IP2PR_IPOIB_FLAGS_EMPTY(ipoib_wait)) {
 
-		result =
-		    _tsIp2prIpoibWaitDestroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
+		result = ip2pr_ipoib_wait_destroy(ipoib_wait,
+						  IP2PR_LOCK_NOT_HELD);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
 	}
-	/* if */
 	return 0;
-}				/* _tsIp2prPathRecordComplete */
+}
 
-/* --------------------------------------------------------------------- */
-/*                                                                       */
-/* Address resolution                                                    */
-/*                                                                       */
-/* --------------------------------------------------------------------- */
-/* ========================================================================= */
-/*.._tsIp2prLinkFindComplete -- complete the resolution of an ip address  */
-static s32 _tsIp2prLinkFindComplete(struct ip2pr_ipoib_wait *ipoib_wait,
+/**
+ * Address resolution
+ */
+
+/* ip2pr_link_find_complete -- complete the resolution of an ip address  */
+static s32 ip2pr_link_find_complete(struct ip2pr_ipoib_wait *ipoib_wait,
 				    s32 status, IP2PR_USE_LOCK use_lock)
 {
 	s32 result = 0;
@@ -922,7 +877,7 @@
 					       (ipoib_wait->prev_timeout * HZ) +
 					       (jiffies & 0x0f),
 					       0,
-					       _tsIp2prPathRecordComplete,
+					       ip2pr_path_record_complete,
 					       ipoib_wait, &ipoib_wait->tid);
 		if (0 != result) {
 
@@ -944,7 +899,7 @@
       done:
 	if (0 < TS_IP2PR_IPOIB_FLAG_GET_FUNC(ipoib_wait)) {
 
-		result = _tsIp2prPathLookupComplete(ipoib_wait->plid,
+		result = ip2pr_path_lookup_complete(ipoib_wait->plid,
 						    status,
 						    NULL,
 						    ipoib_wait->func,
@@ -961,16 +916,15 @@
 	/* if */
 	if (0 < TS_IP2PR_IPOIB_FLAGS_EMPTY(ipoib_wait)) {
 
-		expect = _tsIp2prIpoibWaitDestroy(ipoib_wait, use_lock);
+		expect = ip2pr_ipoib_wait_destroy(ipoib_wait, use_lock);
 		TS_EXPECT(MOD_IP2PR, !(0 > expect));
 	}
 	/* if */
 	return 0;
-} /*_tsIp2prLinkFindComplete  */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prArpQuery -- query arp cache */
-static int tsIp2prArpQuery(struct ip2pr_ipoib_wait *ipoib_wait, u32 * state)
+/* ip2pr_arp_query -- query arp cache */
+static int ip2pr_arp_query(struct ip2pr_ipoib_wait *ipoib_wait, u32 * state)
 {
 	struct neighbour *neigh;
 	extern struct neigh_table arp_tbl;
@@ -989,11 +943,10 @@
 
 		return (-ENOENT);
 	}
-}				/*.._tsIp2prArpQuery */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prLinkFind -- resolve an ip address to a ipoib link address. */
-static s32 _tsIp2prLinkFind(struct ip2pr_ipoib_wait *ipoib_wait)
+/* ip2pr_link_find -- resolve an ip address to a ipoib link address. */
+static s32 ip2pr_link_find(struct ip2pr_ipoib_wait *ipoib_wait)
 {
 	s32 result;
 	u32 state;
@@ -1172,7 +1125,7 @@
 		/*
 		 * Not Lookback. Get the Mac address from arp
 		 */
-		result = tsIp2prArpQuery(ipoib_wait, &state);
+		result = ip2pr_arp_query(ipoib_wait, &state);
 		if ((result) || (state & NUD_FAILED) ||
 		    ((ipoib_wait->hw[0] == 0) &&
 		     (ipoib_wait->hw[1] == 0) &&
@@ -1182,7 +1135,7 @@
 			/*
 			 * No arp entry. Create a Wait entry and send Arp request
 			 */
-			result = _tsIp2prIpoibWaitListInsert(ipoib_wait);
+			result = ip2pr_ipoib_wait_list_insert(ipoib_wait);
 			if (0 > result) {
 
 				TS_TRACE(MOD_IP2PR, T_VERY_VERBOSE,
@@ -1206,7 +1159,7 @@
 	/*
 	 * We have a valid arp entry or this is a loopback interface.
 	 */
-	result = _tsIp2prLinkFindComplete(ipoib_wait, 0, 1);
+	result = ip2pr_link_find_complete(ipoib_wait, 0, 1);
 	if (0 > result) {
 
 		TS_TRACE(MOD_IP2PR, T_VERY_VERBOSE, TRACE_FLOW_WARN,
@@ -1218,16 +1171,14 @@
       error:
 	return result;
 
-}				/* _tsIp2prLinkFind */
+}
 
-/* --------------------------------------------------------------------- */
-/*                                                                       */
-/* Arp packet reception for completions                                  */
-/*                                                                       */
-/* --------------------------------------------------------------------- */
-/* ========================================================================= */
-/*.._tsIp2prArpRecvComplete -- receive all ARP packets. */
-static void _tsIp2prArpRecvComplete(void *arg)
+/**
+ * Arp packet reception for completions
+ */
+
+/* ip2pr_arp_recv_complete -- receive all ARP packets. */
+static void ip2pr_arp_recv_complete(void *arg)
 {
 	struct ip2pr_ipoib_wait *ipoib_wait;
 	struct ip2pr_ipoib_wait *next_wait;
@@ -1257,32 +1208,28 @@
 
 			TS_IP2PR_IPOIB_FLAG_CLR_TASK(ipoib_wait);
 
-			result = _tsIp2prLinkFindComplete(ipoib_wait, 0, 0);
+			result = ip2pr_link_find_complete(ipoib_wait, 0, 0);
 			if (0 > result) {
-
 				TS_TRACE(MOD_IP2PR, T_VERY_VERBOSE,
 					 TRACE_FLOW_WARN,
 					 "FIND: Error <%d> completing address lookup. <%08x>",
 					 result, ipoib_wait->dst_addr);
 
-				result =
-				    _tsIp2prIpoibWaitDestroy(ipoib_wait,
-							     IP2PR_LOCK_HELD);
+				result = ip2pr_ipoib_wait_destroy(ipoib_wait,
+							       IP2PR_LOCK_HELD);
 				TS_EXPECT(MOD_IP2PR, !(0 > result));
-			}	/* if */
+			}
 		}
-		/* if */
 		ipoib_wait = next_wait;
 	}			/* while */
 	spin_unlock_irqrestore(&_tsIp2prLinkRoot.wait_lock, flags);
 
 	return;
-}				/* _tsIp2prArpRecvComplete */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prArpRecv -- receive all ARP packets. */
-static s32 _tsIp2prArpRecv(struct sk_buff *skb, struct net_device *dev,
-			   struct packet_type *pt)
+/* ip2pr_arp_recv -- receive all ARP packets. */
+static s32 ip2pr_arp_recv(struct sk_buff *skb, struct net_device *dev,
+			  struct packet_type *pt)
 {
 	struct ip2pr_ipoib_wait *ipoib_wait;
 	struct ip2pr_ipoib_arp *arp_hdr;
@@ -1353,7 +1300,7 @@
 	 * Schedule the ARP completion.
 	 */
 	if (0 < counter) {
-		INIT_WORK(tqp, _tsIp2prArpRecvComplete,
+		INIT_WORK(tqp, ip2pr_arp_recv_complete,
 			  (void *)(unsigned long)arp_hdr->src_ip);
 
 		schedule_work(tqp);
@@ -1362,11 +1309,10 @@
       done:
 	kfree_skb(skb);
 	return 0;
-}				/* _tsIp2prArpRecv */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prAsyncEventFunc -- IB async event handler, for clearing caches */
-static void _tsIp2prAsyncEventFunc(struct ib_async_event_record *record,
+/* ip2pr_async_event_func -- IB async event handler, for clearing caches */
+static void ip2pr_async_event_func(struct ib_async_event_record *record,
 				   void *arg)
 {
 	struct ip2pr_path_element *path_elmt;
@@ -1389,7 +1335,7 @@
 	 */
 	while (NULL != (path_elmt = _tsIp2prLinkRoot.path_list)) {
 
-		result = _tsIp2prPathElementDestroy(path_elmt);
+		result = ip2pr_path_element_destroy(path_elmt);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
 	}			/* while */
 
@@ -1421,7 +1367,7 @@
 			}
 			/* clear the Gid pr cache */
 			while (NULL != (prn_elmt = sgid_elmt->pr_list)) {
-				_tsIp2PrnDelete(prn_elmt);
+				ip2pr_delete(prn_elmt);
 			}
 			break;
 		}
@@ -1433,11 +1379,10 @@
 		 record->device, record->modifier.port, record->event);
 
 	return;
-}				/* _tsIp2prAsyncEventFunc */
+}
 
-/* ========================================================================= */
-/*.._tsIp2prPathSweepTimerFunc --sweep path cache to reap old entries. */
-static void _tsIp2prPathSweepTimerFunc(void *arg)
+/* ip2pr_path_sweep_timer_func -- sweep path cache to reap old entries. */
+static void ip2pr_path_sweep_timer_func(void *arg)
 {
 	struct ip2pr_path_element *path_elmt;
 	struct ip2pr_path_element *next_elmt;
@@ -1462,7 +1407,7 @@
 					 path_elmt->usage, jiffies,
 					 htonl(path_elmt->dst_addr));
 
-				result = _tsIp2prPathElementDestroy(path_elmt);
+				result = ip2pr_path_element_destroy(path_elmt);
 				TS_EXPECT(MOD_IP2PR, !(0 > result));
 			}
 			/* if */
@@ -1484,7 +1429,7 @@
 						 TRACE_FLOW_INOUT,
 						 "GID: Deleting old <%u:%u>.",
 						 prn_elmt->usage, jiffies);
-					_tsIp2PrnDelete(prn_elmt);
+					ip2pr_delete(prn_elmt);
 				}
 				prn_elmt = next_prn;
 			}
@@ -1499,18 +1444,16 @@
 	tsKernelTimerAdd(&_tsIp2prPathTimer);
 
 	return;
-}				/* _tsIp2prPathSweepTimerFunc */
+}
 
-/* --------------------------------------------------------------------- */
-/*                                                                       */
-/* Path record lookup functions                                          */
-/*                                                                       */
-/* --------------------------------------------------------------------- */
-/* ========================================================================= */
-/*..tsSdpPathRecordLookup -- resolve an ip address to a path record */
-s32 tsIp2prPathRecordLookup(u32 dst_addr, u32 src_addr, u8 localroute,
-			    s32 bound_dev_if, tIP2PR_PATH_LOOKUP_FUNC func,
-			    void *arg, tIP2PR_PATH_LOOKUP_ID * plid)
+/**
+ * Path record lookup functions
+ */
+
+/* ip2pr_path_record_lookup -- resolve an ip address to a path record */
+s32 ip2pr_path_record_lookup(u32 dst_addr, u32 src_addr, u8 localroute,
+			     s32 bound_dev_if, tIP2PR_PATH_LOOKUP_FUNC func,
+			     void *arg, tIP2PR_PATH_LOOKUP_ID * plid)
 {
 	struct ip2pr_path_element *path_elmt;
 	struct ip2pr_ipoib_wait *ipoib_wait;
@@ -1526,15 +1469,15 @@
 	/*
 	 * perform a lookup to see if a path element structure exists.
 	 */
-	path_elmt = _tsIp2prPathElementLookup(dst_addr);
+	path_elmt = ip2pr_path_element_lookup(dst_addr);
 	if (NULL != path_elmt) {
 		/*
 		 * update last used time.
 		 */
 		path_elmt->usage = jiffies;
 
-		result =
-		    _tsIp2prPathLookupComplete(*plid, 0, path_elmt, func, arg);
+		result = ip2pr_path_lookup_complete(*plid, 0, path_elmt, func,
+						    arg);
 		if (0 > result) {
 
 			TS_TRACE(MOD_IP2PR, T_VERBOSE, TRACE_FLOW_WARN,
@@ -1545,7 +1488,7 @@
 	} /* if */
 	else {
 
-		ipoib_wait = _tsIp2prIpoibWaitCreate(*plid,
+		ipoib_wait = ip2pr_ipoib_wait_create(*plid,
 						     dst_addr,
 						     src_addr,
 						     localroute,
@@ -1560,16 +1503,15 @@
 		}
 		/* if */
 		ip2pr_total_req++;
-		result = _tsIp2prLinkFind(ipoib_wait);
+		result = ip2pr_link_find(ipoib_wait);
 		if (0 > result) {
 
 			TS_TRACE(MOD_IP2PR, T_VERBOSE, TRACE_FLOW_WARN,
 				 "PATH: Error <%d> starting address resolution.",
 				 result);
 
-			expect =
-			    _tsIp2prIpoibWaitDestroy(ipoib_wait,
-						     IP2PR_LOCK_NOT_HELD);
+			expect = ip2pr_ipoib_wait_destroy(ipoib_wait,
+							  IP2PR_LOCK_NOT_HELD);
 			TS_EXPECT(MOD_IP2PR, !(0 > expect));
 
 			goto error;
@@ -1579,11 +1521,11 @@
 	return 0;
       error:
 	return result;
-}				/* tsIp2prPathRecordLookup */
+}
+EXPORT_SYMBOL(ip2pr_path_record_lookup);
 
-/* ========================================================================= */
-/*..tsIp2prPathRecordCancel -- cancel a lookup for an address. */
-s32 tsIp2prPathRecordCancel(tIP2PR_PATH_LOOKUP_ID plid)
+/* ip2pr_path_record_cancel -- cancel a lookup for an address. */
+s32 ip2pr_path_record_cancel(tIP2PR_PATH_LOOKUP_ID plid)
 {
 	struct ip2pr_ipoib_wait *ipoib_wait;
 	s32 result;
@@ -1593,7 +1535,7 @@
 		return -ERANGE;
 	}
 	/* if */
-	ipoib_wait = tsIp2prIpoibWaitPlidLookup(plid);
+	ipoib_wait = ip2pr_ipoib_wait_plid_lookup(plid);
 	if (NULL == ipoib_wait) {
 
 		return -ENOENT;
@@ -1619,15 +1561,16 @@
 	if (0 < TS_IP2PR_IPOIB_FLAGS_EMPTY(ipoib_wait)) {
 
 		result =
-		    _tsIp2prIpoibWaitDestroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
+		    ip2pr_ipoib_wait_destroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
 	}
 	/* if */
 	return 0;
-}				/* tsIp2prPathRecordCancel */
+}
+EXPORT_SYMBOL(ip2pr_path_record_cancel);
 
-/*..tsGid2prCancel -- cancel a lookup for an address. */
-s32 tsGid2prCancel(tIP2PR_PATH_LOOKUP_ID plid)
+/* gid2pr_cancel -- cancel a lookup for an address. */
+s32 gid2pr_cancel(tIP2PR_PATH_LOOKUP_ID plid)
 {
 	struct ip2pr_ipoib_wait *ipoib_wait;
 	s32 result;
@@ -1637,7 +1580,7 @@
 		return -ERANGE;
 	}
 	/* if */
-	ipoib_wait = tsIp2prIpoibWaitPlidLookup(plid);
+	ipoib_wait = ip2pr_ipoib_wait_plid_lookup(plid);
 	if (NULL == ipoib_wait) {
 
 		return -ENOENT;
@@ -1656,29 +1599,26 @@
 	TS_IP2PR_IPOIB_FLAG_CLR_TIME(ipoib_wait);
 
 	if (0 < TS_IP2PR_IPOIB_FLAGS_EMPTY(ipoib_wait)) {
-
-		result =
-		    _tsIp2prIpoibWaitDestroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
+		result = ip2pr_ipoib_wait_destroy(ipoib_wait,
+						  IP2PR_LOCK_NOT_HELD);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
 	}
-	/* if */
 	return 0;
-}				/* tsGid2prCancel */
+}
+EXPORT_SYMBOL(gid2pr_cancel);
 
-/* --------------------------------------------------------------------- */
-/*                                                                       */
-/* primary initialization/cleanup functions                              */
-/*                                                                       */
-/* --------------------------------------------------------------------- */
+/**
+ * primary initialization/cleanup functions
+ */
+
 static struct packet_type _sdp_arp_type = {
 	.type = __constant_htons(ETH_P_ARP),
-	.func = _tsIp2prArpRecv,
+	.func = ip2pr_arp_recv,
 	.af_packet_priv = (void *)1,	/* understand shared skbs */
 };
 
-/* ========================================================================= */
-/*.._tsIp2prGidCacheLookup -- Lookup for GID in cache */
-s32 _tsIp2prGidCacheLookup(tTS_IB_GID src_gid, tTS_IB_GID dst_gid,
+/* ip2pr_gid_cache_lookup -- Lookup for GID in cache */
+s32 ip2pr_gid_cache_lookup(tTS_IB_GID src_gid, tTS_IB_GID dst_gid,
 			   struct ib_path_record *path_record,
 			   struct ip2pr_sgid_element **gid_node)
 {
@@ -1739,10 +1679,8 @@
 	return (-ENOENT);
 }
 
-/* ========================================================================= */
-/*.._tsIp2prSrcGidNodeGet --  */
-s32 _tsIp2prSrcGidNodeGet(tTS_IB_GID src_gid,
-			  struct ip2pr_sgid_element **gid_node)
+s32 ip2pr_src_gid_node_get(tTS_IB_GID src_gid,
+			   struct ip2pr_sgid_element **gid_node)
 {
 	struct ip2pr_sgid_element *sgid_elmt;
 	unsigned long flags;
@@ -1763,18 +1701,16 @@
 	return (-EINVAL);
 }
 
-/* ========================================================================= */
-/*.._tsIp2prGidElementAdd -- Add one node to  Source GID List. */
-s32 _tsIp2prGidElementAdd(struct ip2pr_ipoib_wait *ipoib_wait,
-			  struct ib_path_record *path_record)
+/* ip2pr_gid_element_add -- Add one node to  Source GID List. */
+static s32 ip2pr_gid_element_add(struct ip2pr_ipoib_wait *ipoib_wait,
+				 struct ib_path_record *path_record)
 {
 	unsigned long flags;
 	struct ip2pr_sgid_element *gid_node = NULL;
 	struct ip2pr_gid_pr_element *prn_elmt;
 
-	if (_tsIp2prSrcGidNodeGet(ipoib_wait->src_gid, &gid_node)) {
+	if (ip2pr_src_gid_node_get(ipoib_wait->src_gid, &gid_node))
 		return (-EINVAL);
-	}
 
 	prn_elmt = kmem_cache_alloc(_tsIp2prLinkRoot.gid_pr_cache, SLAB_ATOMIC);
 	if (NULL == prn_elmt) {
@@ -1782,8 +1718,7 @@
 			 "PATH: Error Allocating prn memory.");
 		return (-ENOMEM);
 	}
-	memcpy(&prn_elmt->path_record, path_record,
-	       sizeof(*path_record));
+	memcpy(&prn_elmt->path_record, path_record, sizeof(*path_record));
 
 	/*
 	 * Insert into the ccache list
@@ -1803,7 +1738,7 @@
 	return (0);
 }
 
-s32 _tsIp2PrnDelete(struct ip2pr_gid_pr_element *prn_elmt)
+static s32 ip2pr_delete(struct ip2pr_gid_pr_element *prn_elmt)
 {
 	if (NULL != prn_elmt->p_next) {
 
@@ -1821,9 +1756,8 @@
 	return (0);
 }
 
-/* ========================================================================= */
-/*.._tsIp2prSrcGidDelete -- Cleanup one node in  Source GID List. */
-s32 _tsIp2prSrcGidDelete(struct ip2pr_sgid_element *sgid_elmt)
+/* ip2pr_src_gid_delete -- Cleanup one node in  Source GID List. */
+static s32 ip2pr_src_gid_delete(struct ip2pr_sgid_element *sgid_elmt)
 {
 	unsigned long flags;
 	struct ip2pr_gid_pr_element *prn_elmt;
@@ -1834,7 +1768,7 @@
 	 * Clear Path Record List for this Source GID node
 	 */
 	while (NULL != (prn_elmt = sgid_elmt->pr_list)) {
-		_tsIp2PrnDelete(prn_elmt);
+		ip2pr_delete(prn_elmt);
 	}			/* while */
 
 	if (NULL != sgid_elmt->p_next) {
@@ -1855,9 +1789,8 @@
 	return (0);
 }
 
-/* ========================================================================= */
-/*.._tsIp2prSrcGidAdd -- Add one node to  Source GID List. */
-s32 _tsIp2prSrcGidAdd(struct ib_device *hca_device,
+/* ip2pr_src_gid_add -- Add one node to  Source GID List. */
+s32 ip2pr_src_gid_add(struct ib_device *hca_device,
                       tTS_IB_PORT port,
                       enum ib_port_state port_state)
 {
@@ -1904,11 +1837,10 @@
 	return (0);
 }
 
-/* ========================================================================= */
-/*.._tsGid2prComplete -- path lookup complete, save result */
-static s32 _tsGid2prComplete(tTS_IB_CLIENT_QUERY_TID tid, s32 status,
-			     struct ib_path_record *path, s32 remaining,
-			     void *arg)
+/* gid2pr_complete -- path lookup complete, save result */
+static s32 gid2pr_complete(tTS_IB_CLIENT_QUERY_TID tid, s32 status,
+			   struct ib_path_record *path, s32 remaining,
+			   void *arg)
 {
 	s32 result;
 	struct ip2pr_ipoib_wait *ipoib_wait = (struct ip2pr_ipoib_wait *) arg;
@@ -1933,7 +1865,7 @@
 						       TS_IB_PATH_RECORD_FORCE_REMOTE,
 						       TS_IP2PR_DEV_PATH_WAIT,
 						       0,
-						       _tsGid2prComplete,
+						       gid2pr_complete,
 						       ipoib_wait,
 						       &ipoib_wait->tid);
 			if (0 > result) {
@@ -1951,7 +1883,7 @@
 		/*
 		 * Add to cache
 		 */
-		_tsIp2prGidElementAdd(ipoib_wait, path);
+		ip2pr_gid_element_add(ipoib_wait, path);
 		goto callback;
 
 		break;
@@ -1968,11 +1900,10 @@
 	return (0);
 }
 
-/* ========================================================================= */
-/*..tsGid2prLookup -- Resolve a destination GD to Path Record */
-s32 tsGid2prLookup(tTS_IB_GID src_gid, tTS_IB_GID dst_gid, u16 pkey,
-		   tGID2PR_LOOKUP_FUNC funcptr, void *arg,
-		   tIP2PR_PATH_LOOKUP_ID * plid)
+/* gid2pr_lookup -- Resolve a destination GD to Path Record */
+s32 gid2pr_lookup(tTS_IB_GID src_gid, tTS_IB_GID dst_gid, u16 pkey,
+		  tGID2PR_LOOKUP_FUNC funcptr, void *arg,
+		  tIP2PR_PATH_LOOKUP_ID * plid)
 {
 	struct ip2pr_sgid_element *gid_node;
 	s32 result;
@@ -1990,7 +1921,7 @@
 	/*
 	 * Lookup cache first
 	 */
-	if (0 == _tsIp2prGidCacheLookup(src_gid,
+	if (0 == ip2pr_gid_cache_lookup(src_gid,
 					dst_gid, &path_record, &gid_node)) {
 		func = (tGID2PR_LOOKUP_FUNC) funcptr;
 		result =
@@ -2011,11 +1942,7 @@
 		return (-EHOSTUNREACH);
 	}
 
-	ipoib_wait = _tsIp2prIpoibWaitCreate(*plid,
-					     0,
-					     0,
-					     0,
-					     0,
+	ipoib_wait = ip2pr_ipoib_wait_create(*plid, 0, 0, 0, 0,
 					     (void *) funcptr,
 					     arg, LOOKUP_GID2PR);
 	if (NULL == ipoib_wait) {
@@ -2030,9 +1957,9 @@
 	memcpy(ipoib_wait->src_gid, src_gid, sizeof(src_gid));
 	memcpy(ipoib_wait->dst_gid, dst_gid, sizeof(dst_gid));
 
-	result = _tsIp2prIpoibWaitListInsert(ipoib_wait);
+	result = ip2pr_ipoib_wait_list_insert(ipoib_wait);
 	if (0 > result) {
-		_tsIp2prIpoibWaitDestroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
+		ip2pr_ipoib_wait_destroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
 		return (result);
 	}
 
@@ -2047,7 +1974,7 @@
 				       TS_IB_PATH_RECORD_FORCE_REMOTE,
 				       TS_IP2PR_DEV_PATH_WAIT,
 				       0,
-				       _tsGid2prComplete,
+				       gid2pr_complete,
 				       ipoib_wait, &ipoib_wait->tid);
 	if (0 != result) {
 		TS_TRACE(MOD_IP2PR, T_VERBOSE, TRACE_FLOW_WARN,
@@ -2056,17 +1983,17 @@
 
 	return (result);
 }
+EXPORT_SYMBOL(gid2pr_lookup);
 
-/* ========================================================================= */
-/*..tsIp2prSrcGidCleanup -- Cleanup the Source GID List. */
-s32 tsIp2prSrcGidCleanup(void)
+/* ip2pr_src_gid_cleanup -- Cleanup the Source GID List. */
+s32 ip2pr_src_gid_cleanup(void)
 {
 	struct ip2pr_sgid_element *sgid_elmt;
 	s32 result;
 
 	while (NULL != (sgid_elmt = _tsIp2prLinkRoot.src_gid_list)) {
 
-		result = _tsIp2prSrcGidDelete(sgid_elmt);
+		result = ip2pr_src_gid_delete(sgid_elmt);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
 	}			/* while */
 
@@ -2076,9 +2003,8 @@
 	return (0);
 }
 
-/* ========================================================================= */
-/*..tsIp2prSrcGidInit -- initialize the Source GID List. */
-s32 tsIp2prSrcGidInit(void)
+/* ip2pr_src_gid_init -- initialize the Source GID List. */
+s32 ip2pr_src_gid_init(void)
 {
 	s32 result = 0;
 	int i, j;
@@ -2128,9 +2054,8 @@
 				continue;
 			}
 
-			result =
-			    _tsIp2prSrcGidAdd(hca_device, j,
-					      port_prop.port_state);
+			result = ip2pr_src_gid_add(hca_device, j,
+						   port_prop.port_state);
 			if (0 > result) {
 				goto port_err;
 			}
@@ -2145,9 +2070,8 @@
 	return (result);
 }
 
-/* ========================================================================= */
-/*..tsIp2prLinkAddrInit -- initialize the advertisment caches. */
-s32 tsIp2prLinkAddrInit(void)
+/* ip2pr_link_addr_init -- initialize the advertisment caches. */
+s32 ip2pr_link_addr_init(void)
 {
 	s32 result = 0;
 	struct ib_async_event_record evt_rec;
@@ -2223,7 +2147,7 @@
 		evt_rec.device = hca_device;
 		evt_rec.event = IB_PORT_ERROR;
 		result = ib_async_event_handler_register(&evt_rec,
-						       _tsIp2prAsyncEventFunc,
+						       ip2pr_async_event_func,
 						       NULL,
 						       &_tsIp2prAsyncErrHandle
 						       [i]);
@@ -2238,7 +2162,7 @@
 		evt_rec.device = hca_device;
 		evt_rec.event = IB_PORT_ACTIVE;
 		result = ib_async_event_handler_register(&evt_rec,
-						       _tsIp2prAsyncEventFunc,
+						       ip2pr_async_event_func,
 						       NULL,
 						       &_tsIp2prAsyncActHandle
 						       [i]);
@@ -2256,7 +2180,7 @@
 	 */
 	tsKernelTimerInit(&_tsIp2prPathTimer);
 	_tsIp2prPathTimer.run_time = jiffies + TS_IP2PR_PATH_TIMER_INTERVAL;
-	_tsIp2prPathTimer.function = _tsIp2prPathSweepTimerFunc;
+	_tsIp2prPathTimer.function = ip2pr_path_sweep_timer_func;
 	_tsIp2prPathTimer.arg = NULL;
 	tsKernelTimerAdd(&_tsIp2prPathTimer);
 	/*
@@ -2293,11 +2217,10 @@
       error_wait:
       error:
 	return result;
-}				/* tsIp2prLinkAddrInit */
+}
 
-/* ========================================================================= */
-/*..tsIp2prLinkAddrCleanup -- cleanup the advertisment caches. */
-s32 tsIp2prLinkAddrCleanup(void)
+/* ip2pr_link_addr_cleanup -- cleanup the advertisment caches. */
+s32 ip2pr_link_addr_cleanup(void)
 {
 	struct ip2pr_path_element *path_elmt;
 	struct ip2pr_ipoib_wait *ipoib_wait;
@@ -2336,14 +2259,14 @@
 	 */
 	while (NULL != (ipoib_wait = _tsIp2prLinkRoot.wait_list)) {
 
-		result =
-		    _tsIp2prIpoibWaitDestroy(ipoib_wait, IP2PR_LOCK_NOT_HELD);
+		result = ip2pr_ipoib_wait_destroy(ipoib_wait,
+						  IP2PR_LOCK_NOT_HELD);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
 	}			/* while */
 
 	while (NULL != (path_elmt = _tsIp2prLinkRoot.path_list)) {
 
-		result = _tsIp2prPathElementDestroy(path_elmt);
+		result = ip2pr_path_element_destroy(path_elmt);
 		TS_EXPECT(MOD_IP2PR, !(0 > result));
 	}			/* while */
 	/*
@@ -2354,14 +2277,13 @@
 	kmem_cache_destroy(_tsIp2prLinkRoot.user_req);
 
 	return 0;
-}				/* tsIp2prLinkAddrCleanup */
+}
 
-/* ========================================================================= */
-/*..tsIp2prCbInternal -- Callback for IP to Path Record Lookup */
-static s32 _tsIp2prCbInternal(tIP2PR_PATH_LOOKUP_ID plid, s32 status,
-			      u32 src_addr, u32 dst_addr, tTS_IB_PORT hw_port,
-			      struct ib_device *ca, struct ib_path_record *path,
-			      void *usr_arg)
+/* ip2pr_cb_internal -- Callback for IP to Path Record Lookup */
+static s32 ip2pr_cb_internal(tIP2PR_PATH_LOOKUP_ID plid, s32 status,
+			     u32 src_addr, u32 dst_addr, tTS_IB_PORT hw_port,
+			     struct ib_device *ca, struct ib_path_record *path,
+			     void *usr_arg)
 {
 	struct ip2pr_user_req *ureq;
 
@@ -2380,11 +2302,10 @@
 	return (0);
 }
 
-/* ========================================================================= */
-/*..tsIp2prCbInternal -- Callback for Gid to Path Record Lookup */
-static s32 _tsGid2prCbInternal(tIP2PR_PATH_LOOKUP_ID plid, s32 status,
-			       tTS_IB_PORT hw_port, struct ib_device *ca,
-			       struct ib_path_record *path, void *usr_arg)
+/* gid2pr_cb_internal -- Callback for Gid to Path Record Lookup */
+static s32 gid2pr_cb_internal(tIP2PR_PATH_LOOKUP_ID plid, s32 status,
+			      tTS_IB_PORT hw_port, struct ib_device *ca,
+			      struct ib_path_record *path, void *usr_arg)
 {
 	struct ip2pr_user_req *ureq;
 
@@ -2405,9 +2326,8 @@
 	return (0);
 }
 
-/* ========================================================================= */
-/*..tsIp2prUserLookup -- Process a IP to Path Record lookup ioctl request */
-s32 _tsIp2prUserLookup(unsigned long arg)
+/* ip2pr_user_lookup -- Process a IP to Path Record lookup ioctl request */
+s32 ip2pr_user_lookup(unsigned long arg)
 {
 	struct ip2pr_user_req *ureq;
 	struct ip2pr_lookup_param param;
@@ -2432,8 +2352,8 @@
 
 	ureq->status = 0;
 	sema_init(&ureq->sem, 0);
-	status = tsIp2prPathRecordLookup(param.dst_addr, 0, 0, 0,
-					 _tsIp2prCbInternal, ureq, &plid);
+	status = ip2pr_path_record_lookup(param.dst_addr, 0, 0, 0,
+					  ip2pr_cb_internal, ureq, &plid);
 	if (status < 0) {
 		kmem_cache_free(_tsIp2prLinkRoot.user_req, ureq);
 		return (-EFAULT);
@@ -2441,7 +2361,7 @@
 
 	status = down_interruptible(&ureq->sem);
 	if (status) {
-		tsIp2prPathRecordCancel(plid);
+		ip2pr_path_record_cancel(plid);
 		kmem_cache_free(_tsIp2prLinkRoot.user_req, ureq);
 		return (-EINTR);
 	}
@@ -2458,9 +2378,8 @@
 	return (0);
 }
 
-/* ========================================================================= */
-/*..tsGid2prUserLookup -- Process a Gid to Path Record lookup ioctl request */
-s32 _tsGid2prUserLookup(unsigned long arg)
+/* gid2pr_user_lookup -- Process a Gid to Path Record lookup ioctl request */
+s32 gid2pr_user_lookup(unsigned long arg)
 {
 	struct ip2pr_user_req *ureq;
 	struct gid2pr_lookup_param param, *upa;
@@ -2486,8 +2405,8 @@
 
 	ureq->status = 0;
 	sema_init(&ureq->sem, 0);
-	status = tsGid2prLookup(param.src_gid, param.dst_gid, param.pkey,
-				_tsGid2prCbInternal, (void *) ureq, &plid);
+	status = gid2pr_lookup(param.src_gid, param.dst_gid, param.pkey,
+			       gid2pr_cb_internal, (void *) ureq, &plid);
 	if (status < 0) {
 		kmem_cache_free(_tsIp2prLinkRoot.user_req, ureq);
 		return (-EFAULT);
@@ -2495,7 +2414,7 @@
 
 	status = down_interruptible(&ureq->sem);
 	if (status) {
-		tsGid2prCancel(plid);
+		gid2pr_cancel(plid);
 		kmem_cache_free(_tsIp2prLinkRoot.user_req, ureq);
 		return (-EINTR);
 	}
@@ -2514,8 +2433,3 @@
 
 	return (0);
 }
-
-EXPORT_SYMBOL(tsIp2prPathRecordLookup);
-EXPORT_SYMBOL(tsIp2prPathRecordCancel);
-EXPORT_SYMBOL(tsGid2prLookup);
-EXPORT_SYMBOL(tsGid2prCancel);
Index: drivers/infiniband/ulp/sdp/sdp_event.c
===================================================================
--- drivers/infiniband/ulp/sdp/sdp_event.c	(revision 622)
+++ drivers/infiniband/ulp/sdp/sdp_event.c	(working copy)
@@ -686,7 +686,7 @@
 		/*
 		 * cancel address resolution
 		 */
-		result = tsIp2prPathRecordCancel(conn->plid);
+		result = ip2pr_path_record_cancel(conn->plid);
 		TS_EXPECT(MOD_LNX_SDP, !(0 > result));
 		/*
 		 * fall through
Index: drivers/infiniband/ulp/sdp/sdp_post.c
===================================================================
--- drivers/infiniband/ulp/sdp/sdp_post.c	(revision 622)
+++ drivers/infiniband/ulp/sdp/sdp_post.c	(working copy)
@@ -265,12 +265,12 @@
 	TS_SDP_CONN_HOLD(conn);
 	TS_SDP_CONN_UNLOCK(conn);
 
-	result = tsIp2prPathRecordLookup(htonl(conn->dst_addr),
-					 htonl(conn->src_addr),
-					 TS_SDP_OS_SK_LOCALROUTE(conn->sk),
-					 TS_SDP_OS_SK_BOUND_IF(conn->sk),
-					 _sdp_ip2pr_path_complete,
-					 conn, &conn->plid);
+	result = ip2pr_path_record_lookup(htonl(conn->dst_addr),
+					  htonl(conn->src_addr),
+					  TS_SDP_OS_SK_LOCALROUTE(conn->sk),
+					  TS_SDP_OS_SK_BOUND_IF(conn->sk),
+					  _sdp_ip2pr_path_complete,
+					  conn, &conn->plid);
 	TS_SDP_CONN_LOCK(conn);
 
 	if (0 > result) {

-------------- next part --------------
A non-text attachment was scrubbed...
Name: signature.asc
Type: application/pgp-signature
Size: 189 bytes
Desc: This is a digitally signed message part
URL: <http://lists.openfabrics.org/pipermail/general/attachments/20040810/0bd96797/attachment.sig>


More information about the general mailing list
Index: drivers/infiniband/ulp/ipoib/ip2pr_proc.c
===================================================================
--- drivers/infiniband/ulp/ipoib/ip2pr_proc.c	(revision 622)
+++ drivers/infiniband/ulp/ipoib/ip2pr_proc.c	(working copy)
@@ -26,67 +26,37 @@
 static const char _dir_name_root[] = TS_IP2PR_PROC_DIR_NAME;
 static struct proc_dir_entry *_dir_root = NULL;
 
-extern s32 tsIp2prPathElementTableDump(char *buffer,
-				       s32 max_size,
-				       s32 start_index,
-				       long *end_index);
-extern s32 tsIp2prIpoibWaitTableDump(char *buffer,
-				     s32 max_size,
-				     s32 start_index,
-				     long *end_index);
-extern s32 tsIp2prProcRetriesRead(char *buffer,
-				  s32 max_size,
-				  s32 start_index,
+extern s32 ip2pr_path_element_table_dump(char *buffer, s32 max_size,
+					 s32 start_index, long *end_index);
+extern s32 ip2pr_ipoib_wait_table_dump(char *buffer, s32 max_size,
+				       s32 start_index, long *end_index);
+extern s32 ip2pr_proc_retries_read(char *buffer, s32 max_size, s32 start_index,
+				   long *end_index);
+extern s32 ip2pr_proc_timeout_read(char *buffer, s32 max_size, s32 start_index,
+				   long *end_index);
+extern s32 ip2pr_proc_backoff_read(char *buffer, s32 max_size, s32 start_index,
+				   long *end_index);
+extern s32 ip2pr_proc_cache_timeout_read(char *buffer, s32 max_size,
+					 s32 start_index, long *end_index);
+extern int ip2pr_proc_retries_write(struct file *file, const char *buffer,
+				    unsigned long count, void *pos);
+extern int ip2pr_proc_timeout_write(struct file *file, const char *buffer,
+				    unsigned long count, void *pos);
+extern int ip2pr_proc_backoff_write(struct file *file, const char *buffer,
+				    unsigned long count, void *pos);
+extern int ip2pr_proc_cache_timeout_write(struct file *file, const char *buffer,
+					  unsigned long count, void *pos);
+extern int ip2pr_proc_total_req(char *buffer, s32 max_size, s32 start_index,
+				long *end_index);
+extern int ip2pr_proc_arp_timeout(char *buffer, s32 max_size, s32 start_index,
 				  long *end_index);
-extern s32 tsIp2prProcTimeoutRead(char *buffer,
-				  s32 max_size,
-				  s32 start_index,
-				  long *end_index);
-extern s32 tsIp2prProcBackoffRead(char *buffer,
-				  s32 max_size,
-				  s32 start_index,
-				  long *end_index);
-extern s32 tsIp2prProcCacheTimeoutRead(char *buffer,
-				       s32 max_size,
-				       s32 start_index,
-				       long *end_index);
-extern int tsIp2prProcRetriesWrite(struct file *file,
-				   const char *buffer,
-				   unsigned long count,
-				   void *pos);
-extern int tsIp2prProcTimeoutWrite(struct file *file,
-				   const char *buffer,
-				   unsigned long count,
-				   void *pos);
-extern int tsIp2prProcBackoffWrite(struct file *file,
-				   const char *buffer,
-				   unsigned long count,
-				   void *pos);
-extern int tsIp2prProcCacheTimeoutWrite(struct file *file,
-					const char *buffer,
-					unsigned long count,
-					void *pos);
-
-extern int tsIp2prProcTotalReq(char *buffer,
-			       s32 max_size,
-			       s32 start_index,
-			       long *end_index);
-extern int tsIp2prProcArpTimeout(char *buffer,
-				 s32 max_size,
-				 s32 start_index,
+extern int ip2pr_proc_path_timeout(char *buffer, s32 max_size, s32 start_index,
+				   long *end_index);
+extern int ip2pr_proc_total_fail(char *buffer, s32 max_size, s32 start_index,
 				 long *end_index);
-extern int tsIp2prProcPathTimeout(char *buffer,
-				  s32 max_size,
-				  s32 start_index,
-				  long *end_index);
-extern int tsIp2prProcTotalFail(char *buffer,
-				s32 max_size,
-				s32 start_index,
-				long *end_index);
 
-/* ========================================================================= */
-/*.._tsIp2prProcReadParse -- read function for the injection table */
-static s32 _tsIp2prProcReadParse(char *page, char **start, off_t offset,
+/* ip2pr_proc_read_parse -- read function for the injection table */
+static s32 ip2pr_proc_read_parse(char *page, char **start, off_t offset,
 				 s32 count, s32 *eof, void *data)
 {
 	struct ip2pr_proc_sub_entry *sub_entry =
@@ -116,64 +86,63 @@
 	}
 	/* if */
 	return size;
-}				/* _tsIp2prProcReadParse */
+}
 
 static struct ip2pr_proc_sub_entry _file_entry_list[TS_IP2PR_PROC_ENTRIES] = {
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_ARP_WAIT,
 	      name:"arp_wait",
-	      read:tsIp2prIpoibWaitTableDump,
+	      read:ip2pr_ipoib_wait_table_dump,
       write:NULL},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_PATH_TABLE,
 	      name:"path_cache",
-	      read:tsIp2prPathElementTableDump,
+	      read:ip2pr_path_element_table_dump,
       write:NULL},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_MAX_RETRIES,
 	      name:"retries",
-	      read:tsIp2prProcRetriesRead,
-      write:tsIp2prProcRetriesWrite},
+	      read:ip2pr_proc_retries_read,
+      write:ip2pr_proc_retries_write},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_TIMEOUT,
 	      name:"timeout",
-	      read:tsIp2prProcTimeoutRead,
-      write:tsIp2prProcTimeoutWrite},
+	      read:ip2pr_proc_timeout_read,
+      write:ip2pr_proc_timeout_write},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_BACKOUT,
 	      name:"backoff",
-	      read:tsIp2prProcBackoffRead,
-      write:tsIp2prProcBackoffWrite},
+	      read:ip2pr_proc_backoff_read,
+      write:ip2pr_proc_backoff_write},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_CACHE_TIMEOUT,
 	      name:"cache_timeout",
-	      read:tsIp2prProcCacheTimeoutRead,
-      write:tsIp2prProcCacheTimeoutWrite},
+	      read:ip2pr_proc_cache_timeout_read,
+      write:ip2pr_proc_cache_timeout_write},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_TOTAL_REQ,
 	      name:"total_req",
-	      read:tsIp2prProcTotalReq,
+	      read:ip2pr_proc_total_req,
       write:NULL},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_ARP_TIMEOUT,
 	      name:"arp_timeout",
-	      read:tsIp2prProcArpTimeout,
+	      read:ip2pr_proc_arp_timeout,
       write:NULL},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_PATH_TIMEOUT,
 	      name:"path_timeout",
-	      read:tsIp2prProcPathTimeout,
+	      read:ip2pr_proc_path_timeout,
       write:NULL},
       {entry:NULL,
 	      type:TS_IP2PR_PROC_ENTRY_TOTAL_FAIL,
 	      name:"total_fail",
-	      read:tsIp2prProcTotalFail,
+	      read:ip2pr_proc_total_fail,
       write:NULL}
 };
 
-/* ========================================================================= */
-/*..tsIp2prProcFsCleanup -- cleanup the proc filesystem entries  */
-s32 tsIp2prProcFsCleanup(void)
+/* ip2pr_proc_fs_cleanup -- cleanup the proc filesystem entries  */
+s32 ip2pr_proc_fs_cleanup(void)
 {
 	struct ip2pr_proc_sub_entry *sub_entry;
 	s32 counter;
@@ -200,11 +169,10 @@
 		 "PROC: /proc filesystem cleanup complete.");
 
 	return 0;
-}				/* tsIp2prProcFsCleanup */
+}
 
-/* ========================================================================= */
-/*..tsIp2prProcFsInit -- initialize the proc filesystem entries  */
-s32 tsIp2prProcFsInit(void)
+/* ip2pr_proc_fs_init -- initialize the proc filesystem entries  */
+s32 ip2pr_proc_fs_init(void)
 {
 	struct ip2pr_proc_sub_entry *sub_entry;
 	s32 result;
@@ -262,7 +230,7 @@
 			goto error;
 		}
 		/* if */
-		sub_entry->entry->read_proc = _tsIp2prProcReadParse;
+		sub_entry->entry->read_proc = ip2pr_proc_read_parse;
 		sub_entry->entry->write_proc = sub_entry->write;
 		sub_entry->entry->data = sub_entry;
 		sub_entry->entry->owner = THIS_MODULE;
@@ -270,6 +238,6 @@
 
 	return 0;		/* success */
       error:
-	(void)tsIp2prProcFsCleanup();
+	(void)ip2pr_proc_fs_cleanup();
 	return result;
-}				/* tsIp2prProcFsInit */
+}
Index: drivers/infiniband/ulp/ipoib/ip2pr_mod.c
===================================================================
--- drivers/infiniband/ulp/ipoib/ip2pr_mod.c	(revision 622)
+++ drivers/infiniband/ulp/ipoib/ip2pr_mod.c	(working copy)
@@ -27,53 +27,45 @@
 MODULE_DESCRIPTION("IB path record lookup module");
 MODULE_LICENSE("Dual BSD/GPL");
 
-extern s32 tsIp2prLinkAddrInit(void
-    );
-extern s32 tsIp2prLinkAddrCleanup(void
-    );
-extern s32 _tsIp2prUserLookup(unsigned long arg);
-extern s32 _tsGid2prUserLookup(unsigned long arg);
-extern s32 tsIp2prProcFsInit(void
-    );
-extern s32 tsIp2prProcFsCleanup(void
-    );
-extern s32 tsIp2prSrcGidInit(void
-    );
-extern s32 tsIp2prSrcGidCleanup(void
-    );
+extern s32 ip2pr_link_addr_init(void);
+extern s32 ip2pr_link_addr_cleanup(void);
+extern s32 ip2pr_user_lookup(unsigned long arg);
+extern s32 gid2pr_user_lookup(unsigned long arg);
+extern s32 ip2pr_proc_fs_init(void);
+extern s32 ip2pr_proc_fs_cleanup(void);
+extern s32 ip2pr_src_gid_init(void);
+extern s32 ip2pr_src_gid_cleanup(void);
 
 static int ip2pr_major_number = 240;
-static int _tsIp2prOpen(struct inode *inode, struct file *fp);
-static int _tsIp2prClose(struct inode *inode, struct file *fp);
-static int _tsIp2prIoctl(struct inode *inode, struct file *fp, unsigned int cmd,
+static int ip2pr_open(struct inode *inode, struct file *fp);
+static int ip2pr_close(struct inode *inode, struct file *fp);
+static int ip2pr_ioctl(struct inode *inode, struct file *fp, unsigned int cmd,
 			 unsigned long arg);
 
 static struct file_operations ip2pr_fops = {
 	.owner = THIS_MODULE,
-	.ioctl = _tsIp2prIoctl,
-	.open = _tsIp2prOpen,
-	.release = _tsIp2prClose,
+	.ioctl = ip2pr_ioctl,
+	.open = ip2pr_open,
+	.release = ip2pr_close,
 };
 
-/* ========================================================================= */
-/*..tsIp2prOpen -- Driver Open Entry Point */
-static int _tsIp2prOpen(struct inode *inode, struct file *fp) {
+/* ip2pr_open -- Driver Open Entry Point */
+static int ip2pr_open(struct inode *inode, struct file *fp)
+{
 	TS_ENTER(MOD_IP2PR);
 	return 0;
 }
 
-/* ========================================================================= */
-/*..tsIp2prClose -- Driver Close Entry Point */
-static int _tsIp2prClose(struct inode *inode, struct file *fp) {
+/* ip2pr_close -- Driver Close Entry Point */
+static int ip2pr_close(struct inode *inode, struct file *fp) {
 	TS_ENTER(MOD_IP2PR);
 	return 0;
 }
 
-/* ========================================================================= */
-/*..tsIp2prIoctl -- Driver Ioctl Entry Point */
-static int _tsIp2prIoctl
-    (struct inode *inode,
-     struct file *fp, unsigned int cmd, unsigned long arg) {
+/* ip2pr_ioctl -- Driver Ioctl Entry Point */
+static int ip2pr_ioctl(struct inode *inode, struct file *fp, unsigned int cmd,
+		       unsigned long arg)
+{
 	int result;
 
 	if (_IOC_TYPE(cmd) != IP2PR_IOC_MAGIC) {
@@ -82,10 +74,10 @@
 
 	switch (cmd) {
 	case IP2PR_IOC_LOOKUP_REQ:
-		result = _tsIp2prUserLookup(arg);
+		result = ip2pr_user_lookup(arg);
 		break;
 	case GID2PR_IOC_LOOKUP_REQ:
-		result = _tsGid2prUserLookup(arg);
+		result = gid2pr_user_lookup(arg);
 		break;
 	default:
 		result = -EINVAL;
@@ -94,15 +86,13 @@
 	return (result);
 }
 
-/* --------------------------------------------------------------------- */
-/*                                                                       */
-/* Path Record lookup host module load/unload functions                  */
-/*                                                                       */
-/* --------------------------------------------------------------------- */
-/* ========================================================================= */
-/*..prlookup_init -- initialize the PathRecord Lookup host module */
-int __init tsIp2prDriverInitModule(void
-    ) {
+/**
+ * Path Record lookup host module load/unload functions
+ */
+
+/* ip2pr_driver_init_module -- initialize the PathRecord Lookup host module */
+int __init ip2pr_driver_init_module(void)
+{
 	s32 result = 0;
 
 	TS_TRACE(MOD_IP2PR, T_VERBOSE, TRACE_FLOW_INOUT,
@@ -117,26 +107,26 @@
 	if (ip2pr_major_number == 0)
 		ip2pr_major_number = result;
 
-	result = tsIp2prProcFsInit();
+	result = ip2pr_proc_fs_init();
 	if (0 > result) {
 		TS_REPORT_FATAL(MOD_IP2PR, "Init: Error creating proc entries");
 		unregister_chrdev(ip2pr_major_number, IP2PR_DEVNAME);
 		return (result);
 	}
 
-	result = tsIp2prLinkAddrInit();
+	result = ip2pr_link_addr_init();
 	if (0 > result) {
 		TS_REPORT_FATAL(MOD_IP2PR, "Device resource allocation failed");
-		(void)tsIp2prProcFsCleanup();
+		(void)ip2pr_proc_fs_cleanup();
 		unregister_chrdev(ip2pr_major_number, IP2PR_DEVNAME);
 		return (result);
 	}
 
-	result = tsIp2prSrcGidInit();
+	result = ip2pr_src_gid_init();
 	if (0 > result) {
 		TS_REPORT_FATAL(MOD_IP2PR, "Gid resource allocation failed");
-		(void)tsIp2prLinkAddrCleanup();
-		(void)tsIp2prProcFsCleanup();
+		(void)ip2pr_link_addr_cleanup();
+		(void)ip2pr_proc_fs_cleanup();
 		unregister_chrdev(ip2pr_major_number, IP2PR_DEVNAME);
 		return (result);
 	}
@@ -144,8 +134,8 @@
 	return (result);
 }
 
-static void __exit tsIp2prDriverCleanupModule(void
-    ) {
+static void __exit ip2pr_driver_cleanup_module(void)
+{
 	TS_TRACE(MOD_IP2PR, T_VERBOSE, TRACE_FLOW_INOUT,
 		 "INIT: Path Record Lookup module load.");
 
@@ -156,17 +146,17 @@
 	/*
 	 * Src Gid Cleanup
 	 */
-	(void)tsIp2prSrcGidCleanup();
+	(void)ip2pr_src_gid_cleanup();
 	/*
 	 * link level addressing services.
 	 */
-	(void)tsIp2prLinkAddrCleanup();
+	(void)ip2pr_link_addr_cleanup();
 
 	/*
 	 * proc tables
 	 */
-	(void)tsIp2prProcFsCleanup();
+	(void)ip2pr_proc_fs_cleanup();
 }
 
-module_init(tsIp2prDriverInitModule);
-module_exit(tsIp2prDriverCleanupModule);
+module_init(ip2pr_driver_init_module);
+module_exit(ip2pr_driver_cleanup_module);